package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcSjly;
import org.apache.ibatis.annotations.Param;

/**
 * 硬探针、软探针Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcSjlyMapper 
{
    /**
     * 查询硬探针、软探针
     * 
     * @param id 硬探针、软探针主键
     * @return 硬探针、软探针
     */
    public TcSjly selectTcSjlyById(Long id);

    /**
     * 查询硬探针、软探针列表
     * 
     * @param tcSjly 硬探针、软探针
     * @return 硬探针、软探针集合
     */
    public List<TcSjly> selectTcSjlyList(TcSjly tcSjly);

    /**
     * 新增硬探针、软探针
     * 
     * @param tcSjly 硬探针、软探针
     * @return 结果
     */
    public int insertTcSjly(TcSjly tcSjly);

    /**
     * 修改硬探针、软探针
     * 
     * @param tcSjly 硬探针、软探针
     * @return 结果
     */
    public int updateTcSjly(TcSjly tcSjly);

    /**
     * 删除硬探针、软探针
     * 
     * @param id 硬探针、软探针主键
     * @return 结果
     */
    public int deleteTcSjlyById(Long id);

    /**
     * 批量删除硬探针、软探针
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcSjlyByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
