package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcSgjipTop5;
import com.ruoyi.tcZz.domain.TcSjly;
import com.ruoyi.tcZz.service.ITcSjlyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 硬探针、软探针Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "硬探针、软探针")
@RequestMapping("/tcZz/networkSecurity/ryz")
public class TcSjlyController extends BaseController {
    @Autowired
    private ITcSjlyService tcSjlyService;

    /**
     * 查询硬探针、软探针列表
     */
    @ApiOperation(value = "查询硬探针、软探针列表", response = TcSjly.class)
    @GetMapping("/list")
    public TableDataInfo list(TcSjly tcSjly) {
        startPage();
        List<TcSjly> list = tcSjlyService.selectTcSjlyList(tcSjly);
        return getDataTable(list);
    }

    /**
     * 导出硬探针、软探针列表
     */
    @ApiOperation(value = "导出硬探针、软探针列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcSjly tcSjly) {
        List<TcSjly> list = tcSjlyService.selectTcSjlyList(tcSjly);
        ExcelUtil<TcSjly> util = new ExcelUtil<TcSjly>(TcSjly.class);
        util.exportExcel(response, list, "硬探针、软探针数据");
    }

    /**
     * 获取硬探针、软探针详细信息
     */
    @ApiOperation(value = "获取硬探针、软探针详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcSjlyService.selectTcSjlyById(id));
    }

    /**
     * 新增硬探针、软探针
     */
    @ApiOperation(value = "新增硬探针、软探针")
    @PostMapping
    public AjaxResult add(@RequestBody TcSjly tcSjly) {
        return toAjax(tcSjlyService.insertTcSjly(tcSjly));
    }

    /**
     * 修改硬探针、软探针
     */
    @ApiOperation(value = "修改硬探针、软探针")
    @PutMapping
    public AjaxResult edit(@RequestBody TcSjly tcSjly) {
        return toAjax(tcSjlyService.updateTcSjly(tcSjly));
    }

    /**
     *
     */
    @ApiOperation(value = "修改硬探针、软探针")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcSjlyService.deleteTcSjlyByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcSjly> util = new ExcelUtil<TcSjly>(TcSjly.class);
        List<TcSjly> tcSjlyList = util.importExcel(file.getInputStream());
        tcSjlyService.importUser(tcSjlyList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcSjlyService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcSjly> util = new ExcelUtil<TcSjly>(TcSjly.class);
        util.importTemplateExcel(response, " 硬探针、软探针");
    }
}
